pub struct ServiceAccountInfoJson {
pub project_id: String,
pub private_key_id: String,
pub private_key: String,
pub client_email: String,
pub client_id: String,
pub auth_uri: String,
pub token_uri: String,
pub client_x509_cert_url: String,
}Expand description
Example for a valid ServiceAccountInfoJson:
{
"type": "service_account",
"project_id": "PROJECT_ID",
"private_key_id": "0000000000000000000000000000000000000000",
"private_key": "PRIVATE_KEY_IN_BASE64_WITH_PEM_HEADER_AND_FOOTER",
"client_email": "service_account@??????.gserviceaccount.com",
"client_id": "000000000000000000000",
"auth_uri": "https://accounts.google.com/o/oauth2/auth",
"token_uri": "https://oauth2.googleapis.com/token",
"auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
"client_x509_cert_url": "URL_TO_PUBLIC_KEY",
"universe_domain": "googleapis.com"
}
This JSON can be downloaded in the google console service account section during the key generation. This JSON cannot be downloaded twice! A new key must be generated, if the file gets lost!
Fields
project_id: Stringprivate_key_id: Stringprivate_key: Stringclient_email: Stringclient_id: Stringauth_uri: Stringtoken_uri: Stringclient_x509_cert_url: StringTrait Implementations
sourceimpl Debug for ServiceAccountInfoJson
impl Debug for ServiceAccountInfoJson
sourceimpl<'de> Deserialize<'de> for ServiceAccountInfoJson
impl<'de> Deserialize<'de> for ServiceAccountInfoJson
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more