pub enum Usage {
Show 275 variants
Custom(String),
CloudPlatform,
CloudPlatformReadOnly,
AdExchangeBuyer,
AdMobReadOnly,
AdMobReport,
AdSenseHost,
AdminReportsAuditReadOnly,
AdminReportsUsageReadOnly,
AdminDataTransfer,
AdminDataTransferReadOnly,
AdminChromePrinters,
AdminChromePrintersReadOnly,
AdminDirectoryCustomer,
AdminDirectoryCustomerReadOnly,
AdminDirectoryDeviceChromeOS,
AdminDirectoryDeviceChromeOSReadOnly,
AdminDirectoryDeviceMobile,
AdminDirectoryDeviceMobileAction,
AdminDirectoryDeviceMobileReadOnly,
AdminDirectoryDomain,
AdminDirectoryDomainReadOnly,
AdminDirectoryGroup,
AdminDirectoryGroupMember,
AdminDirectoryGroupMemberReadOnly,
AdminDirectoryGroupReadOnly,
AdminDirectoryOrgUnit,
AdminDirectoryOrgUnitReadOnly,
AdminDirectoryResourceCalendar,
AdminDirectoryResourceCalendarReadOnly,
AdminDirectoryRoleManagement,
AdminDirectoryRoleManagementReadOnly,
AdminDirectoryUser,
AdminDirectoryUserAlias,
AdminDirectoryUserAliasReadOnly,
AdminDirectoryUserReadOnly,
AdminDirectoryUserSecurity,
AdminDirectoryUserSchema,
AdminDirectoryUserSchemaReadOnly,
Analytics,
AnalyticsReadOnly,
AndroidManagement,
AppEngineAdmin,
Mail,
CalendarFeeds,
M8Feeds,
Documents,
Drive,
Forms,
FormsCurrentOnly,
Groups,
ScriptDeployments,
ScriptDeploymentsReadOnly,
ScriptMetrics,
ScriptProcesses,
ScriptProjects,
ScriptProjectsReadOnly,
Spreadsheets,
UserInfoEmail,
BigQuery,
BigQueryInsertData,
DevStorageFullControl,
DevStorageReadOnly,
DevStorageReadWrite,
Blogger,
BloggerReadOnly,
Books,
Calendar,
CalendarEvents,
CalendarEventsReadOnly,
CalendarReadOnly,
CalendarSettingsReadOnly,
DdmConversions,
DfaReporting,
DfaTrafficking,
BigTableAdmin,
BigTableAdminCluster,
BigTableAdminInstance,
BigTableAdminTable,
CloudBigTableAdmin,
CloudBigTableAdminCluster,
CloudBigTableAdminTable,
CloudBilling,
CloudBillingReadOnly,
NDevCloudDnsReadOnly,
NDevCloudDnsReadWrite,
CloudDebugger,
NDevCloudMan,
NDevCloudManReadOnly,
DataStore,
CloudIdentityDevicesLookup,
CloudIdentityGroups,
CloudIdentityGroupsReadOnly,
CloudKms,
LoggingWrite,
LoggingRead,
LoggingAdmin,
Monitoring,
MonitoringRead,
MonitoringWrite,
CloudLanguage,
Compute,
ComputeReadOnly,
PubSub,
CloudRuntimeConfig,
SqlServiceAdmin,
CloudSearch,
CloudSearchDebug,
CloudSearchIndexing,
CloudSearchQuery,
CloudSearchSettings,
CloudSearchSettingsIndexing,
CloudSearchSettingsQuery,
CloudSearchStats,
CloudSearchStatsIndexing,
SourceFullControl,
SourceReadOnly,
SourceReadWrite,
SpannerAdmin,
SpannerData,
TraceAppend,
CloudTranslation,
CloudVision,
Content,
DriveActivity,
DriveActivityReadOnly,
AppsLicensing,
FirebaseMessaging,
Firebase,
FirebaseReadOnly,
FitnessActivityRead,
FitnessActivityWrite,
FitnessBloodGlucoseRead,
FitnessBloodGlucoseWrite,
FitnessBloodPressureRead,
FitnessBloodPressureWrite,
FitnessBodyRead,
FitnessBodyWrite,
FitnessBodyTemperatureRead,
FitnessBodyTemperatureWrite,
FitnessHeartRateRead,
FitnessHeartRateWrite,
FitnessLocationWrite,
FitnessLocationRead,
FitnessNutritionRead,
FitnessNutritionWrite,
FitnessOxygenSaturationRead,
FitnessOxygenSaturationWrite,
FitnessReproductiveHealthRead,
FitnessReproductiveHealthWrite,
FitnessSleepRead,
FitnessSleepWrite,
Genomics,
MailAddonsCurrentActionCompose,
MailAddonsCurrentMessageAction,
MailAddonsCurrentMessageMetaData,
MailAddonsCurrentMessageReadOnly,
MailCompose,
MailInsert,
MailLabels,
MailMetaData,
MailModify,
MailReadOnly,
MailSend,
MailSettingsBasic,
MailSettingsSharing,
AnalyticsEdit,
AnalyticsManageUsers,
AnalyticsManageUsersReadOnly,
AnalyticsProVision,
AnalyticsUserDeletion,
ChatDelete,
ChatMembershipsReadOnly,
ChatMemberships,
ChatMembershipsApp,
ChatMessages,
ChatMessagesCreate,
ChatMessagesReactions,
ChatMessagesReactionsCreate,
ChatMessagesReactionsReadOnly,
ChatMessagesReadOnly,
ChatSpaces,
ClassroomAnnouncements,
ChatSpacesReadOnly,
ChatSpacesCreate,
ClassroomAnnouncementsReadOnly,
ClassroomCourses,
ClassroomCoursesReadOnly,
ClassroomCourseworkMe,
ClassroomCourseworkMeReadOnly,
ClassroomCourseworkStudents,
ClassroomCourseworkStudentsReadOnly,
ClassroomCourseworkMaterials,
ClassroomCourseworkMaterialsReadOnly,
ClassroomGuardianLinksMeReadOnly,
ClassroomGuardianLinksStudents,
ClassroomGuardianLinksStudentsReadOnly,
ClassroomProfileEmails,
ClassroomProfilePhotos,
ClassroomPushNotifications,
ClassroomRosters,
ClassroomRostersReadOnly,
ClassroomStudentSubmissionsMeReadOnly,
ClassroomStudentSubmissionsStudentsReadOnly,
ClassroomTopics,
ClassroomTopicsReadOnly,
YoutubeAnalyticsReadOnly,
YoutubeAnalyticsMonetaryReadOnly,
YoutubePartnerChannelAudit,
YouTubeForceSsl,
YoutubeReadOnly,
YoutubeUpload,
YoutubePartner,
YoutubeChannelMembershipsCreator,
Youtube,
TagManagerPublish,
TagManagerReadOnly,
TagManagerManageUsers,
TagManagerManageAccounts,
TagManagerEditContainerVersions,
TagManagerEditContainers,
TagManagerDeleteContainers,
StreetViewPublish,
ServiceManagement,
ServiceManagementReadOnly,
DoubleClickSearch,
SasPortal,
PhotosLibrarySharing,
PhotosLibraryReadOnlyAppCreatedData,
PhotosLibraryReadOnly,
PhotosLibraryEditAppCreatedData,
PhotosLibraryAppendOnly,
PhotosLibrary,
UserInfoProfile,
UserPhoneNumbersRead,
UserOrganizationRead,
ContactsReadOnly,
DirectoryReadOnly,
UserAddressesRead,
UserBirthdayRead,
UserEmailsRead,
UserGenderRead,
ManufacturerCenter,
ContactsOtherReadOnly,
Indexing,
AppsAlerts,
AppsOrder,
AppsOrderReadOnly,
AppsGroupsMigration,
AppsGroupsSettings,
EDiscoveryReadOnly,
EDiscovery,
Tasks,
TasksReadOnly,
SpreadsheetsReadOnly,
Presentations,
PresentationsReadOnly,
DriveReadOnly,
DriveFile,
SiteVerificationVerifyOnly,
SiteVerification,
WebmastersReadOnly,
Webmasters,
AndroidPublisher,
DriveAppData,
Games,
AndroidEnterprise,
DriveScripts,
DrivePhotosReadOnly,
DriveMetaDataReadOnly,
DriveMetaData,
DocumentsReadOnly,
Email,
OpenId,
Profile,
}Expand description
This enum contains all usage types defined by google (late 2023). See here for more information.
Variants
Custom(String)
For own purposes
CloudPlatform
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
CloudPlatformReadOnly
View your data across Google Cloud services and see the email address of your Google Account
AdExchangeBuyer
Manage your Ad Exchange buyer account configuration
AdMobReadOnly
See your AdMob data
AdMobReport
See your AdMob data
AdSenseHost
View and manage your AdSense host data and associated accounts
AdminReportsAuditReadOnly
View audit reports for your G Suite domain
AdminReportsUsageReadOnly
View audit reports for your G Suite domain
AdminDataTransfer
View and manage data transfers between users in your organization
AdminDataTransferReadOnly
View data transfers between users in your organization
AdminChromePrinters
See, add, edit, and permanently delete the printers that your organization can use with Chrome
AdminChromePrintersReadOnly
See the printers that your organization can use with Chrome
AdminDirectoryCustomer
View and manage customer related information
AdminDirectoryCustomerReadOnly
View customer related information
AdminDirectoryDeviceChromeOS
View and manage your Chrome OS devices’ metadata
AdminDirectoryDeviceChromeOSReadOnly
View your Chrome OS devices’ metadata
AdminDirectoryDeviceMobile
View and manage your mobile devices’ metadata
AdminDirectoryDeviceMobileAction
Manage your mobile devices by performing administrative tasks
AdminDirectoryDeviceMobileReadOnly
View your mobile devices’ metadata
AdminDirectoryDomain
View and manage the provisioning of domains for your customers
AdminDirectoryDomainReadOnly
View domains related to your customers
AdminDirectoryGroup
View and manage the provisioning of groups on your domain
AdminDirectoryGroupMember
View and manage group subscriptions on your domain
AdminDirectoryGroupMemberReadOnly
View group subscriptions on your domain
AdminDirectoryGroupReadOnly
View groups on your domain
AdminDirectoryOrgUnit
View and manage organization units on your domain
AdminDirectoryOrgUnitReadOnly
View organization units on your domain
AdminDirectoryResourceCalendar
View and manage the provisioning of calendar resources on your domain
AdminDirectoryResourceCalendarReadOnly
View calendar resources on your domain
AdminDirectoryRoleManagement
Manage delegated admin roles for your domain
AdminDirectoryRoleManagementReadOnly
View delegated admin roles for your domain
AdminDirectoryUser
View and manage the provisioning of users on your domain
AdminDirectoryUserAlias
View and manage user aliases on your domain
AdminDirectoryUserAliasReadOnly
View user aliases on your domain
AdminDirectoryUserReadOnly
See info about users on your domain
AdminDirectoryUserSecurity
Manage data access permissions for users on your domain
AdminDirectoryUserSchema
View and manage the provisioning of user schemas on your domain
AdminDirectoryUserSchemaReadOnly
View user schemas on your domain
Analytics
View and manage your Google Analytics data
AnalyticsReadOnly
See and download your Google Analytics data
AndroidManagement
Manage Android devices and apps for your customers
AppEngineAdmin
View and manage your applications deployed on Google App Engine
Read, compose, send, and permanently delete all your email from Gmail
CalendarFeeds
See, edit, share, and permanently delete all the calendars you can access using Google Calendar
M8Feeds
See, edit, download, and permanently delete your contacts
Documents
See, edit, create, and delete all your Google Docs documents
Drive
See, edit, create, and delete all of your Google Drive files
Forms
View and manage your forms in Google Drive
FormsCurrentOnly
View and manage forms that this application has been installed in
Groups
View and manage your Google Groups
ScriptDeployments
Create and update Google Apps Script deployments
ScriptDeploymentsReadOnly
View Google Apps Script deployments
ScriptMetrics
View Google Apps Script project’s metrics
ScriptProcesses
View Google Apps Script processes
ScriptProjects
Create and update Google Apps Script projects
ScriptProjectsReadOnly
View Google Apps Script projects
Spreadsheets
See, edit, create, and delete all your Google Sheets spreadsheets
UserInfoEmail
See your primary Google Account email address
BigQuery
View and manage your data in Google BigQuery and see the email address for your Google Account
BigQueryInsertData
Insert data into Google BigQuery
DevStorageFullControl
Manage your data and permissions in Cloud Storage and see the email address for your Google Account
DevStorageReadOnly
View your data in Google Cloud Storage
DevStorageReadWrite
Manage your data in Cloud Storage and see the email address of your Google Account
Blogger
Manage your Blogger account
BloggerReadOnly
View your Blogger account
Books
Manage your books
Calendar
See, edit, share, and permanently delete all the calendars you can access using Google Calendar
CalendarEvents
View and edit events on all your calendars
CalendarEventsReadOnly
View events on all your calendars
CalendarReadOnly
See and download any calendar you can access using your Google Calendar
CalendarSettingsReadOnly
View your Calendar settings
DdmConversions
Manage DoubleClick Digital Marketing conversions
DfaReporting
View and manage DoubleClick for Advertisers reports
DfaTrafficking
View and manage your DoubleClick Campaign Manager’s (DCM) display ad campaigns
BigTableAdmin
Administer your Cloud Bigtable tables and clusters
BigTableAdminCluster
Administer your Cloud Bigtable clusters
BigTableAdminInstance
Administer your Cloud Bigtable clusters
BigTableAdminTable
Administer your Cloud Bigtable tables
CloudBigTableAdmin
Administer your Cloud Bigtable tables and clusters
CloudBigTableAdminCluster
Administer your Cloud Bigtable clusters
CloudBigTableAdminTable
Administer your Cloud Bigtable tables
CloudBilling
View and manage your Google Cloud Platform billing accounts
CloudBillingReadOnly
View your Google Cloud Platform billing accounts
NDevCloudDnsReadOnly
View your DNS records hosted by Google Cloud DNS
NDevCloudDnsReadWrite
View and manage your DNS records hosted by Google Cloud DNS
CloudDebugger
Use Stack driver Debugger
NDevCloudMan
View and manage your Google Cloud Platform management resources and deployment status information
NDevCloudManReadOnly
View your Google Cloud Platform management resources and deployment status information
DataStore
View and manage your Google Cloud Datastore data
CloudIdentityDevicesLookup
See your device details
CloudIdentityGroups
See, change, create, and delete any of the Cloud Identity Groups that you can access, including the members of each group
CloudIdentityGroupsReadOnly
See any Cloud Identity Groups that you can access, including group members and their emails
CloudKms
View and manage your keys and secrets stored in Cloud Key Management Service
LoggingWrite
Submit log data for your projects
LoggingRead
View log data for your projects
LoggingAdmin
Administrate log data for your projects
Monitoring
View and write monitoring data for all of your Google and third-party Cloud and API projects
MonitoringRead
View monitoring data for all of your Google Cloud and third-party projects
MonitoringWrite
Publish metric data to your Google Cloud projects
CloudLanguage
Apply machine learning models to reveal the structure and meaning of text
Compute
View and manage your Google Compute Engine resources
ComputeReadOnly
View your Google Compute Engine resources
PubSub
View and manage Pub/Sub topics and subscriptions
CloudRuntimeConfig
Manage your Google Cloud Platform services’ runtime configuration
SqlServiceAdmin
Manage your Google SQL Service instances
CloudSearch
Index and serve your organization’s data with Cloud Search
CloudSearchDebug
Index and serve your organization’s data with Cloud Search
CloudSearchIndexing
Index and serve your organization’s data with Cloud Search
CloudSearchQuery
Search your organization’s data in the Cloud Search index
CloudSearchSettings
Index and serve your organization’s data with Cloud Search
CloudSearchSettingsIndexing
Index and serve your organization’s data with Cloud Search
CloudSearchSettingsQuery
Index and serve your organization’s data with Cloud Search
CloudSearchStats
Index and serve your organization’s data with Cloud Search
CloudSearchStatsIndexing
Index and serve your organization’s data with Cloud Search
SourceFullControl
Manage your source code repositories
SourceReadOnly
View the contents of your source code repositories
SourceReadWrite
Manage the contents of your source code repositories
SpannerAdmin
Administer your Spanner databases
SpannerData
View and manage the contents of your Spanner databases
TraceAppend
Write Trace data for a project or application
CloudTranslation
Translate text from one language to another using Google Translate
CloudVision
Apply machine learning models to understand and label images
Content
Manage your product listings and accounts for Google Shopping
DriveActivity
View and add to the activity record of files in your Google Drive
DriveActivityReadOnly
View the activity record of files in your Google Drive
AppsLicensing
View and manage G Suite licenses for your domain
FirebaseMessaging
Send messages and manage messaging subscriptions for your Firebase applications
Firebase
View and administer all your Firebase data and settings
FirebaseReadOnly
View all your Firebase data and settings
FitnessActivityRead
Use Google Fit to see and store your physical activity data
FitnessActivityWrite
Add to your Google Fit physical activity data
FitnessBloodGlucoseRead
See info about your blood glucose in Google Fit. I consent to Google sharing my blood glucose information with this app.
FitnessBloodGlucoseWrite
Add info about your blood glucose to Google Fit. I consent to Google using my blood glucose information with this app.
FitnessBloodPressureRead
See info about your blood pressure in Google Fit. I consent to Google sharing my blood pressure information with this app.
FitnessBloodPressureWrite
Add info about your blood pressure in Google Fit. I consent to Google using my blood pressure information with this app.
FitnessBodyRead
See info about your body measurements in Google Fit
FitnessBodyWrite
Add info about your body measurements to Google Fit
FitnessBodyTemperatureRead
See info about your body temperature in Google Fit. I consent to Google sharing my body temperature information with this app.
FitnessBodyTemperatureWrite
Add to info about your body temperature in Google Fit. I consent to Google using my body temperature information with this app.
FitnessHeartRateRead
See your heart rate data in Google Fit. I consent to Google sharing my heart rate information with this app.
FitnessHeartRateWrite
Add to your heart rate data in Google Fit. I consent to Google using my heart rate information with this app.
FitnessLocationWrite
Add to your Google Fit location data
FitnessLocationRead
See your Google Fit speed and distance data
FitnessNutritionRead
See info about your nutrition in Google Fit
FitnessNutritionWrite
Add to info about your nutrition in Google Fit
FitnessOxygenSaturationRead
See info about your oxygen saturation in Google Fit. I consent to Google sharing my oxygen saturation information with this app.
FitnessOxygenSaturationWrite
Add info about your oxygen saturation in Google Fit. I consent to Google using my oxygen saturation information with this app.
FitnessReproductiveHealthRead
See info about your reproductive health in Google Fit. I consent to Google sharing my reproductive health information with this app.
FitnessReproductiveHealthWrite
Add info about your reproductive health in Google Fit. I consent to Google using my reproductive health information with this app.
FitnessSleepRead
See your sleep data in Google Fit. I consent to Google sharing my sleep information with this app.
FitnessSleepWrite
Add to your sleep data in Google Fit. I consent to Google using my sleep information with this app.
Genomics
View and manage Genomics data
MailAddonsCurrentActionCompose
Manage drafts and send emails when you interact with the add-on
MailAddonsCurrentMessageAction
View your email messages when you interact with the add-on
MailAddonsCurrentMessageMetaData
View your email message metadata when the add-on is running
MailAddonsCurrentMessageReadOnly
View your email messages when the add-on is running
MailCompose
Manage drafts and send emails
MailInsert
Add emails into your Gmail mailbox
MailLabels
See and edit your email labels
MailMetaData
View your email message metadata such as labels and headers, but not the email body
MailModify
Read, compose, and send emails from your Gmail account
MailReadOnly
iew your email messages and settings
MailSend
Send email on your behalf
MailSettingsBasic
See, edit, create, or change your email settings and filters in Gmail
MailSettingsSharing
Manage your sensitive mail settings, including who can manage your mail
AnalyticsEdit
Edit Google Analytics management entities
AnalyticsManageUsers
Manage Google Analytics Account users by email address
AnalyticsManageUsersReadOnly
View Google Analytics user permissions
AnalyticsProVision
Create a new Google Analytics account along with its default property and view
AnalyticsUserDeletion
Manage Google Analytics user deletion requests
ChatDelete
Delete conversations and spaces & remove access to associated files in Google Chat
ChatMembershipsReadOnly
View members in Google Chat conversations.
ChatMemberships
View, add, and remove members from conversations in Google Chat
ChatMembershipsApp
Add and remove itself from conversations in Google Chat
ChatMessages
View, compose, send, update, and delete messages, and add, view, and delete reactions to messages.
ChatMessagesCreate
Compose and send messages in Google Chat
ChatMessagesReactions
View, add, and delete reactions to messages in Google Chat
ChatMessagesReactionsCreate
Add reactions to messages in Google Chat
ChatMessagesReactionsReadOnly
View reactions to messages in Google Chat
ChatMessagesReadOnly
View messages and reactions in Google Chat
ChatSpaces
Create conversations and spaces and view or update metadata (including history settings) in Google Chat
ClassroomAnnouncements
View and manage announcements in Google Classroom
ChatSpacesReadOnly
View chat and spaces in Google Chat
ChatSpacesCreate
Create new conversations in Google Chat
ClassroomAnnouncementsReadOnly
View announcements in Google Classroom
ClassroomCourses
See, edit, create, and permanently delete your Google Classroom classes
ClassroomCoursesReadOnly
View your Google Classroom classes
ClassroomCourseworkMe
See, create and edit coursework items including assignments, questions, and grades
ClassroomCourseworkMeReadOnly
View your course work and grades in Google Classroom
ClassroomCourseworkStudents
Manage course work and grades for students in the Google Classroom classes you teach and view the course work and grades for classes you administer
ClassroomCourseworkStudentsReadOnly
Google Classroom classes you teach or administer
ClassroomCourseworkMaterials
See, edit, and create classwork materials in Google Classroom
ClassroomCourseworkMaterialsReadOnly
See all classwork materials for your Google Classroom classes
ClassroomGuardianLinksMeReadOnly
View your Google Classroom guardians
ClassroomGuardianLinksStudents
View and manage guardians for students in your Google Classroom classes
ClassroomGuardianLinksStudentsReadOnly
View guardians for students in your Google Classroom classes
ClassroomProfileEmails
View the email addresses of people in your classes
ClassroomProfilePhotos
View the profile photos of people in your classes
ClassroomPushNotifications
Receive notifications about your Google Classroom data
ClassroomRosters
Manage your Google Classroom class rosters
ClassroomRostersReadOnly
View your Google Classroom class rosters
ClassroomStudentSubmissionsMeReadOnly
View your course work and grades in Google Classroom
ClassroomStudentSubmissionsStudentsReadOnly
View course work and grades for students in the Google Classroom classes you teach or administer
ClassroomTopics
See, create, and edit topics in Google Classroom
ClassroomTopicsReadOnly
View topics in Google Classroom
YoutubeAnalyticsReadOnly
View YouTube Analytics reports for your YouTube content
YoutubeAnalyticsMonetaryReadOnly
View monetary and non-monetary YouTube Analytics reports for your YouTube content
YoutubePartnerChannelAudit
View private information of your YouTube channel relevant during the audit process with a YouTube partner
YouTubeForceSsl
See, edit, and permanently delete your YouTube videos, ratings, comments and captions
YoutubeReadOnly
View your YouTube account
YoutubeUpload
Manage your YouTube videos
YoutubePartner
View and manage your assets and associated content on YouTube
YoutubeChannelMembershipsCreator
See a list of your current active channel members, their current level, and when they became a member
Youtube
Manage your YouTube account
TagManagerPublish
Publish your Google Tag Manager container versions
TagManagerReadOnly
View your Google Tag Manager container and its subcomponents
TagManagerManageUsers
Manage user permissions of your Google Tag Manager account and container
TagManagerManageAccounts
View and manage your Google Tag Manager accounts
TagManagerEditContainerVersions
Manage your Google Tag Manager container versions
TagManagerEditContainers
Manage your Google Tag Manager container and its subcomponents, excluding versioning and publishing
TagManagerDeleteContainers
Delete your Google Tag Manager containers
StreetViewPublish
Publish and manage your 360 photos on Google Street View
ServiceManagement
Manage your Google API service configuration
ServiceManagementReadOnly
View your Google API service configuration
DoubleClickSearch
View and manage your advertising data in DoubleClick Search
SasPortal
Read, create, update, and delete your SAS Portal data.
PhotosLibrarySharing
Manage and add to shared albums on your behalf
PhotosLibraryReadOnlyAppCreatedData
Manage photos added by this app
PhotosLibraryReadOnly
View your Google Photos library
PhotosLibraryEditAppCreatedData
Edit the info in your photos, videos, and albums created within this app, including titles, descriptions, and covers
PhotosLibraryAppendOnly
Add to your Google Photos library
PhotosLibrary
See, upload, and organize items in your Google Photos library
UserInfoProfile
See your personal info, including any personal info you’ve made publicly available
UserPhoneNumbersRead
See and download your personal phone numbers
UserOrganizationRead
See your education, work history and org info
ContactsReadOnly
See and download your contacts
DirectoryReadOnly
See and download your organization’s GSuite directory
UserAddressesRead
View your street addresses
UserBirthdayRead
See and download your exact date of birth
UserEmailsRead
See and download all of your Google Account email addresses
UserGenderRead
See your gender
ManufacturerCenter
Manage your product listings for Google Manufacturer Center
ContactsOtherReadOnly
See and download contact info automatically saved in your “Other contacts”
Indexing
Submit data to Google for indexing
AppsAlerts
See and delete your domain’s G Suite alerts, and send alert feedback
AppsOrder
Manage users on your domain
AppsOrderReadOnly
Manage users on your domain
AppsGroupsMigration
Upload messages to any Google group in your domain
AppsGroupsSettings
View and manage the settings of a G Suite group
EDiscoveryReadOnly
View your eDiscovery data
EDiscovery
Manage your eDiscovery data
Tasks
Create, edit, organize, and delete all your tasks
TasksReadOnly
View your tasks
SpreadsheetsReadOnly
See all your Google Sheets spreadsheets
Presentations
See, edit, create, and delete all your Google Slides presentations
PresentationsReadOnly
See all your Google Slides presentations
DriveReadOnly
See and download all your Google Drive files
DriveFile
See, edit, create, and delete only the specific Google Drive files you use with this app
SiteVerificationVerifyOnly
Manage your new site verifications with Google
SiteVerification
Manage the list of sites and domains you control
WebmastersReadOnly
View Search Console data for your verified sites
Webmasters
View and manage Search Console data for your verified sites
AndroidPublisher
View and manage your Google Play Developer account
DriveAppData
See, create, and delete its own configuration data in your Google Drive
Games
Create, edit, and delete your Google Play Games activity
AndroidEnterprise
Manage corporate Android devices
DriveScripts
Modify your Google Apps Script scripts’ behavior
DrivePhotosReadOnly
View the photos, videos and albums in your Google Photos
DriveMetaDataReadOnly
See information about your Google Drive files
DriveMetaData
View and manage metadata of files in your Google Drive
DocumentsReadOnly
See all your Google Docs documents
See your primary Google Account email address
OpenId
Associate you with your personal info on Google
Profile
See your personal info, including any personal info you’ve made publicly available